#include "MainWindow.h"
#include <QDebug>
#include <QMenu>
#include <QMenuBar>
#include <QWebEngineScript>


MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent),
      view(new QWebEngineView)
{
    setCentralWidget(view);
    QAction *quit = new QAction("&Quit", this);
    QAction *listize = new QAction("Create &List from selection", this);
    
    QMenu *file;
    file = menuBar()->addMenu("&File");
    file->addAction(quit);
    
    QMenu *tools;
    tools = menuBar()->addMenu("&Tools");
    tools->addAction(listize);
    
    view->setUrl(commandLineUrlArgument());
    view->resize(1024, 750);
    view->show();
    
    connect(quit, &QAction::triggered, qApp, QApplication::quit);
    connect(listize, &QAction::triggered, this, &MainWindow::InsertUnorderedList);
    connect(view, &QWebEngineView::loadFinished, this, &MainWindow::finishLoading);
}

void MainWindow::InsertUnorderedList()
{
    view->triggerPageAction(QWebEnginePage::InsertUnorderedList);
    qDebug() << "Highlighted paragraphs should have been converted to an unordered list with no loss of content.";
}

void MainWindow::finishLoading(bool)
{
    view->page()->runJavaScript("document.documentElement.contentEditable = true", QWebEngineScript::ApplicationWorld);
    qDebug() << "contentEditable set to true with JS.";
}

QUrl MainWindow::commandLineUrlArgument()
{
    const QStringList args = qApp->arguments();
    for (const QString &arg : args.mid(1)) {
        if (!arg.startsWith(QLatin1Char('-')))
            qDebug() << "User passed url as argument: " << QUrl::fromUserInput(arg);
            return QUrl::fromUserInput(arg);
    }
    qDebug() << "No url argument passed. Using default local ipsum.xhtml file.";
    QString url = "file://" + qApp->applicationDirPath() + "/ipsum.xhtml";
    qDebug () << QUrl(url);
    return QUrl(url);
}
